"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = Checkbox;

var _react = _interopRequireDefault(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const Title = _styledComponents.default.h3`
  padding: 16px 0;
  line-height: 200%;
  font-size: 18px;
  font-weight: 400;
  line-height: 150%;
  box-sizing: border-box;
  font-family: 'Noto Sans CJK TC', sans-serif;
  width: 320px;
  margin: 0;
`;
const CheckboxWrapper = _styledComponents.default.section`
  * {
    font-style: normal;
    font-weight: 400;
    font-size: 18px;
    line-height: 150%;
    list-style: none;
    box-sizing: border-box;
    margin: 0;
    font-family: 'Noto Sans CJK TC', sans-serif;
    padding: 0;
  }
  width: 320px;
  display: flex;
  flex-direction: column;
  padding: 16px 24px 20px;
`;
const CheckboxOptionList = _styledComponents.default.ul`
  position: relative;
  margin: 0;
  padding: 4px 0;
  max-height: 240px;
  overflow-y: auto;
`;
const CheckboxOption = _styledComponents.default.li`
  color: #000928;
  width: 100%;
  cursor: pointer;
  padding: 8px 0;
  color: #000928;
  text-align: left;
  .container {
    display: block;
    position: relative;
    padding-left: 35px;
    cursor: pointer;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
    input {
      position: absolute;
      opacity: 0;
      cursor: pointer;
      height: 0;
      width: 0;
      &:checked {
        background: red;
      }
    }
    .checkmark {
      position: absolute;
      top: 2.5px;
      left: 5px;
      height: 20px;
      width: 20px;
      border: 2px solid rgba(0, 9, 40, 0.3);
      border-radius: 3px;
      &:after {
        content: '';
        position: absolute;
        display: none;
      }
    }
    input:checked ~ .checkmark {
      background: #04295e;
      &:after {
        display: block;
      }
    }
    .checkmark:after {
      top: 50%;
      left: 45%;
      width: 7px;
      height: 14px;
      border: solid #f6f6f5;
      border-width: 0 2px 2px 0;
      transform: rotate(45deg) translate(-50%, -50%);
      transform-origin: center top 0px;
    }
  }
`;
const defaultTitle = '這是複選題';
/**
 *  @param {Object} props
 *  @param {import('../typedef').Option[]} props.options
 *  @param {string} props.title
 *  @param {string[]} props.checkedValue
 *  @param {Function} props.onChange
 *  @return React.ReactElement
 */

function Checkbox({
  title = defaultTitle,
  checkedValue = [],
  ...props
}) {
  const chooseOption = option => {
    if (checkedValue.indexOf(option) > -1) {
      props.onChange(checkedValue.filter(item => item !== option));
    } else {
      props.onChange(checkedValue.concat(option));
    }
  };

  const optionItem = props.options.map(option => /*#__PURE__*/_react.default.createElement(CheckboxOption, {
    key: `option-${option.id}`
  }, /*#__PURE__*/_react.default.createElement("label", {
    className: "container",
    htmlFor: `option-${option.id}`
  }, option.name, /*#__PURE__*/_react.default.createElement("input", {
    type: "checkbox",
    id: `option-${option.id}`,
    value: option.value,
    onChange: e => {
      chooseOption(e.target.value);
    }
  }), /*#__PURE__*/_react.default.createElement("span", {
    className: "checkmark"
  }))));
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(CheckboxWrapper, null, /*#__PURE__*/_react.default.createElement(Title, null, title), /*#__PURE__*/_react.default.createElement(CheckboxOptionList, null, optionItem)));
}