"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = Dropdown;

var _react = _interopRequireWildcard(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const Title = _styledComponents.default.h3`
  padding: 16px 0;
  line-height: 200%;
  font-size: 18px;
  font-weight: 400;
  line-height: 150%;
  box-sizing: border-box;
  font-family: 'Noto Sans CJK TC', sans-serif;
  width: 320px;
  margin: 0;
`;
const DropdownOptionList = _styledComponents.default.ul`
  position: relative;
  margin: 0;
  padding: 4px 0;
  max-height: 240px;
  overflow-y: auto;
  background: #ffffff;
  &::before {
    content: '';
    position: absolute;
    top: 0;
    right: 16px;
    left: 16px;
    height: 1px;
    background-color: #e0e0e0;
  }
`;
const DropdownOption = _styledComponents.default.li`
  color: #000928;
  width: 100%;
  cursor: pointer;
  padding: 8px 16px;
  color: #000928;
  text-align: left;
  &:hover {
    color: #fff;
    background-color: #04295e;
    cursor: pointer;
  }
`;
const DropdownWrapper = _styledComponents.default.section`
  * {
    font-style: normal;
    font-weight: 400;
    font-size: 18px;
    line-height: 150%;
    box-sizing: border-box;
    font-family: 'Noto Sans CJK TC', sans-serif;
  }
  border-radius: 6px;
  border: 1px solid;
  padding: 1px;
  width: 320px;
  margin: 0 auto;
  display: flex;
  flex-direction: column;
  margin: 0 0 24px;
`;
const DropdownInput = _styledComponents.default.div`
  box-sizing: border-box;
  width: 100%;
  position: relative;
  cursor: pointer;
  font-size: 18px;
  padding: 1px;
  background: #ffffff;
  input {
    width: 100%;
    padding: 12px 48px 12px 16px;
    outline: none;
    border: none;
  }
  .arrow {
    position: absolute;
    top: 42%;
    right: 16px;
    width: 0;
    height: 0;
    border-style: solid;
    border-width: 10px 10px 0 10px;
    border-color: #04295e transparent transparent transparent;
  }
  ${props => props.isListOpen && `.arrow {transform: rotate(180deg);}`}
`;
const defaultTitle = '這是選項>=4的單選題';
/**
 *  @param {Object} props
 *  @param {import('../typedef').Option[]} props.options
 *  @param {string} props.title
 *  @param {string} props.checkedValue
 *  @param {Function} props.onChange
 *  @return React.ReactElement
 */

function Dropdown({
  title = defaultTitle,
  ...props
}) {
  const inputRef = (0, _react.useRef)(null);
  const [isListOpen, setIsListOpen] = (0, _react.useState)(false);

  const focusInput = () => {
    inputRef.current.focus();
    inputRef.current.style.borderColor = '#04295e';
  };

  const toggleList = () => {
    setIsListOpen(isListOpen => !isListOpen);
    focusInput();
  };

  const chooseOption = option => {
    toggleList();
    props.onChange(option.value);
    inputRef.current.children[0].value = option.name;
  };

  const optionItem = props.options.map(option => /*#__PURE__*/_react.default.createElement(DropdownOption, {
    onClick: () => chooseOption(option),
    key: `option-${option.id}`
  }, option.name));
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(Title, null, title), /*#__PURE__*/_react.default.createElement(DropdownWrapper, null, /*#__PURE__*/_react.default.createElement(DropdownInput, {
    ref: inputRef,
    onClick: toggleList,
    isListOpen: isListOpen
  }, /*#__PURE__*/_react.default.createElement("input", {
    readOnly: true,
    placeholder: "\u8ACB\u9078\u64C7"
  }), /*#__PURE__*/_react.default.createElement("span", {
    className: "arrow"
  })), isListOpen && /*#__PURE__*/_react.default.createElement(DropdownOptionList, null, optionItem)));
}