"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = Questionnaire;

var _question = _interopRequireDefault(require("./question"));

var _questionCard = _interopRequireDefault(require("./question-card"));

var _result = _interopRequireDefault(require("./result"));

var _react = _interopRequireWildcard(require("react"));

var _cloneDeep = _interopRequireDefault(require("lodash/cloneDeep"));

var _difference = _interopRequireDefault(require("lodash/difference"));

var _intersection = _interopRequireDefault(require("lodash/intersection"));

var _landing = _interopRequireDefault(require("./landing"));

var _defaultLayout = _interopRequireDefault(require("./layout/default-layout"));

var _embeddedCode = require("./draft/embedded-code");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const _ = {
  cloneDeep: _cloneDeep.default,
  difference: _difference.default,
  intersection: _intersection.default
};
/**
 *  @param {Object} opts
 *  @param {import('./typedef').Form} opts.form
 *  @param {boolean} [opts.enableDebugViewer=false]
 *  @return {React.ReactElement}
 */

function Questionnaire({
  form,
  enableDebugViewer = false
}) {
  var _userAnswers$currentQ;

  if (!Array.isArray(form === null || form === void 0 ? void 0 : form.fields)) {
    return /*#__PURE__*/_react.default.createElement("h3", null, "There is no question to answer");
  }

  const copyForm = (0, _react.useMemo)(() => createFormData(form), [form]);
  const emptyUserAnswers = (0, _react.useMemo)(() => createEmptyUserAnswers(copyForm.fields.length), [copyForm.fields.length]);
  const [userAnswers, setUserAnswers] = (0, _react.useState)(emptyUserAnswers);
  const [currentQuestion, setCurrentQuestion] = (0, _react.useState)(copyForm.fields[0]);
  const [currentFormCondition, setCurrentFormCondition] = (0, _react.useState)(null);
  let debugViewerJsx = null;

  if (enableDebugViewer) {
    debugViewerJsx = /*#__PURE__*/_react.default.createElement("div", {
      style: {
        position: 'fixed',
        right: '10px',
        top: '30%',
        height: '50vh',
        overflow: 'scroll'
      }
    }, /*#__PURE__*/_react.default.createElement("pre", {
      id: "json"
    }, currentFormCondition ? JSON.stringify(currentFormCondition, null, 4) : 'No form condition matched'));
  } // The question has been answered


  if (((_userAnswers$currentQ = userAnswers[currentQuestion.number]) === null || _userAnswers$currentQ === void 0 ? void 0 : _userAnswers$currentQ.length) > 0) {
    const matchedFormCondition = matchConditions(userAnswers, copyForm.conditions);

    if (matchedFormCondition) {
      if (enableDebugViewer) {
        if (matchedFormCondition.id !== (currentFormCondition === null || currentFormCondition === void 0 ? void 0 : currentFormCondition.id)) {
          setCurrentFormCondition(matchedFormCondition);
        }
      }

      const {
        answer,
        next,
        goOut
      } = matchedFormCondition;

      if (answer) {
        var _copyForm$answers;

        return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, debugViewerJsx, /*#__PURE__*/_react.default.createElement(_result.default, {
          resultData: (_copyForm$answers = copyForm.answers) === null || _copyForm$answers === void 0 ? void 0 : _copyForm$answers.find(a => a.id === answer.id)
        }), /*#__PURE__*/_react.default.createElement("div", {
          style: {
            marginTop: '60px'
          }
        }, /*#__PURE__*/_react.default.createElement(_embeddedCode.EmbeddedCodeBlock, {
          getData: () => {
            return {
              caption: '',
              embeddedCode: (form === null || form === void 0 ? void 0 : form.feedback) || ''
            };
          }
        })));
      }

      if (goOut) {
        // TODO: render GoOut component
        return /*#__PURE__*/_react.default.createElement("div", null, "render goOut component");
      }

      if (!next) {
        // The program should not enter this condition.
        // If it does, then the form data is created wrongly.
        return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, debugViewerJsx, /*#__PURE__*/_react.default.createElement(_result.default, {
          resultData: {
            name: `Next question is not specified`
          }
        }));
      }

      const nextQ = copyForm.fields.find(q => q.id === next.id);

      if (nextQ.id === currentQuestion.id) {
        return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, debugViewerJsx, /*#__PURE__*/_react.default.createElement(_result.default, {
          resultData: {
            name: `Next question is not configured right. The next question name is ${nextQ.name}`
          }
        }));
      } // Go to next queustion


      setCurrentQuestion(nextQ);
    } else {
      return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, debugViewerJsx, /*#__PURE__*/_react.default.createElement(_result.default, {
        resultData: {
          name: 'There is no matched condition'
        }
      }));
    }
  }

  return /*#__PURE__*/_react.default.createElement(_defaultLayout.default, null, debugViewerJsx, /*#__PURE__*/_react.default.createElement(_landing.default, {
    form: form
  }), /*#__PURE__*/_react.default.createElement(_questionCard.default, {
    isFristPage: userAnswers[0].length === 0
  }, /*#__PURE__*/_react.default.createElement(_question.default, _extends({
    key: currentQuestion.id
  }, currentQuestion, {
    onAnswer:
    /**
     *  @param {string[]} a
     */
    a => {
      const newUserAnswers = [...userAnswers];
      newUserAnswers[currentQuestion.number] = a;
      setUserAnswers(newUserAnswers);
    }
  }))));
}
/**
 *  The function compares the `condition` and `answer` objects.
 *  If `answer` matches `condition`, return true, otherwise, return false.
 *
 *  @param {string[]} answer
 *  @param {import('./typedef').Condition} condition
 *  @return {boolean}
 */


function matchCondition(answer, condition) {
  // no answer
  if (answer.length === 0) {
    return false;
  }

  switch (condition.compare) {
    case 'not':
      {
        var _condition$option;

        // Check if there is no any answer to match any option
        return _.intersection(answer, condition === null || condition === void 0 ? void 0 : (_condition$option = condition.option) === null || _condition$option === void 0 ? void 0 : _condition$option.map(o => o.value)).length === 0;
      }

    case 'include':
      {
        var _condition$option2, _condition$option3;

        // Check if answers include all options
        return answer.length >= (condition === null || condition === void 0 ? void 0 : (_condition$option2 = condition.option) === null || _condition$option2 === void 0 ? void 0 : _condition$option2.length) && _.intersection(answer, condition === null || condition === void 0 ? void 0 : (_condition$option3 = condition.option) === null || _condition$option3 === void 0 ? void 0 : _condition$option3.map(o => o.value)).length === condition.option.length;
      }

    case 'exclude':
      {
        // TODO: add compare logics
        return false;
      }

    case 'is':
    default:
      {
        var _condition$option4, _condition$option5;

        // Check if exactly match
        return answer.length === (condition === null || condition === void 0 ? void 0 : (_condition$option4 = condition.option) === null || _condition$option4 === void 0 ? void 0 : _condition$option4.length) && _.difference(answer, condition === null || condition === void 0 ? void 0 : (_condition$option5 = condition.option) === null || _condition$option5 === void 0 ? void 0 : _condition$option5.map(o => o.value)).length === 0;
      }
  }
}
/**
 *  For loop all form conditions,
 *  and check if user answers matches any of those form conditions.
 *  If matched, return the matched form condition.
 *  Otherwise, return `null`
 *  @param {string[][]} userAnswers
 *  @param {import('./typedef').FormCondition[]} formConditions
 *  @return {import('./typedef').FormCondition}
 */


function matchConditions(userAnswers, formConditions) {
  let matchedFormCondition = null;

  for (const fc of formConditions) {
    let matches = [];

    for (const c of fc.condition) {
      const questionNo = c.formField.number;
      matches.push(matchCondition(userAnswers[questionNo], c));
    }

    let matched = false;

    if (fc.type === 'AND') {
      matched = matches.indexOf(false) === -1;
    }
    /* cs.type === 'OR'*/
    else {
      matched = matches.indexOf(true) > -1;
    }

    if (matched) {
      matchedFormCondition = fc;
      break;
    }
  }

  return matchedFormCondition;
}
/**
 *  This function
 *  1. copies the form data object to avoid modifying the original one.
 *  2. sorts `questions` and `conditions` according to `sortOrder` and `order` properties.
 *  3. adds `number` property in `questions[]` and `conditons[].condition[].formField`
 *
 *  @param {import('./typedef').Form} form
 *  @return {import('./typedef').Form} new deep copy of form
 */


function createFormData(form) {
  const copyForm = _.cloneDeep(form); // sort question by sortOrder


  copyForm.fields.sort((a, b) => {
    return a.sortOrder - b.sortOrder;
  }); // Raw question object has `id` and `sortOrder` properties.
  // `id` is auto incremented by database;
  // `sortOrder` is manually input by editors.
  //  We need to handle the corner cases like
  //  1. `sortOrder`s are identical
  //  2. questions' order is not equal to `id`s' order
  //  Therefore, we append the `number` property in each question.

  applyQuestionNumber(copyForm.fields);

  if (Array.isArray(copyForm === null || copyForm === void 0 ? void 0 : copyForm.conditions)) {
    // sort conditions by order
    copyForm.conditions.sort((a, b) => {
      return a.order - b.order;
    });
    applyQuestionNumberInConditions(copyForm.conditions, copyForm.fields);
  }

  return copyForm;
}
/**
 *  Since we have multiple choice question, we use array to store answers of a question.
 *  Therefore, empty user answers are a two dimension array.
 *
 *  @param {number} questionNumber
 *  @return {string[][]}
 */


function createEmptyUserAnswers(questionNumber) {
  const rtn = [];

  for (let i = 0; i < questionNumber; i++) {
    rtn.push([]);
  }

  return rtn;
}
/**
 *  The raw form question objects does not contain `number` property.
 *  This function adds `number` property in each question according to the question order.
 *
 *  @param {import('./typedef').Question[]} questions
 */


function applyQuestionNumber(questions) {
  // append question number
  for (let i = 0; i < questions.length; i++) {
    const q = questions[i];
    q.number = i;
  }
}
/**
 *  This function adds `number` property into `formConditions[].condition[].formField`.
 *
 *  @param {import('./typedef').FormCondition[]} formConditions
 *  @param {import('./typedef').Question[]} questions
 */


function applyQuestionNumberInConditions(formConditions, questions) {
  for (const fc of formConditions) {
    for (const c of fc.condition) {
      if (c.formField) {
        var _questions$find;

        c.formField.number = (_questions$find = questions.find(q => q.id === c.formField.id)) === null || _questions$find === void 0 ? void 0 : _questions$find.number;
      }
    }
  }
}