"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = Result;

var _react = _interopRequireDefault(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _draftJs = require("draft-js");

var _entityDecorator = _interopRequireDefault(require("./draft/entity-decorator"));

var _blockRedenderFn = require("./draft/block-redender-fn");

var _buttons = _interopRequireDefault(require("./form/buttons"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// eslint-disable-line
const blockRendererFn = block => {
  const atomicBlockObj = (0, _blockRedenderFn.atomicBlockRenderer)(block);
  return atomicBlockObj;
};

const ResultWrapper = _styledComponents.default.div`
  background: #ffffff;
  border: 2px solid #000928;
  border-radius: 6px;
  max-width: 640px;
  margin: 0 auto;
`;
const InfoWrapper = _styledComponents.default.div`
  padding: 20px;
  @media screen and (min-width: 768px) {
    padding: 32px 40px;
  }
  .DraftEditor-root {
    font-family: 'Noto Sans CJK TC', sans-serif;
    font-style: normal;
    font-weight: 400;
    font-size: 16px;
    line-height: 200%;
    color: rgba(0, 9, 40, 0.66);
    @media screen and (min-width: 768px) {
      font-size: 18px;
    }
    div + div {
      margin-top: 16px;
    }
    ul {
      list-style: none;
      padding-left: 0;
      margin-top: 4px;
      .public-DraftStyleDefault-depth1 {
        margin-left: 1.5rem;
      }
      li {
        display: flex;
        ::before {
          content: '';
          display: block;
          min-width: 3px;
          height: 3px;
          border-radius: 50%;
          background: rgba(0, 9, 40, 0.66);
          margin: 0 0.75rem;
          transform: translate(0, 1rem);
        }
      }
    }
  }
`;
const ButtonWrapper = _styledComponents.default.div`
  border-top: 2px solid #000928;
  padding: 20px;
  display: flex;
  justify-content: center;
  @media screen and (min-width: 768px) {
    padding: 32px 40px;
  }
`;
const ResultName = _styledComponents.default.h1`
  font-family: 'Noto Serif TC', sans-serif;
  font-style: normal;
  font-weight: 700;
  font-size: 24px;
  line-height: 150%;
  color: #000928;
  @media screen and (min-width: 768px) {
    font-size: 32px;
  }
`;
const UpdateTime = _styledComponents.default.p`
  font-family: 'Noto Sans CJK TC', sans-serif;
  font-style: normal;
  font-weight: 400;
  font-size: 14px;
  line-height: 21px;
  color: #000928;
  opacity: 0.3;
`;

function Result({
  resultData
}) {
  const content = resultData.content || {
    blocks: [],
    entityMap: {}
  };
  const contentState = (0, _draftJs.convertFromRaw)(content);

  const editorState = _draftJs.EditorState.createWithContent(contentState, _entityDecorator.default);

  const updateTime = new Date(resultData.updatedAt || resultData.createdAt);
  const formattedTime = `${updateTime.getFullYear()}/${updateTime.getMonth() + 1}/${updateTime.getDate()}`;
  return /*#__PURE__*/_react.default.createElement(ResultWrapper, null, /*#__PURE__*/_react.default.createElement(InfoWrapper, null, /*#__PURE__*/_react.default.createElement(ResultName, null, resultData.name), /*#__PURE__*/_react.default.createElement(UpdateTime, null, formattedTime, " \u66F4\u65B0"), /*#__PURE__*/_react.default.createElement(_draftJs.Editor, {
    editorState: editorState,
    readOnly: true,
    blockRendererFn: blockRendererFn
  })), /*#__PURE__*/_react.default.createElement(ButtonWrapper, null, /*#__PURE__*/_react.default.createElement(_buttons.default, {
    title: "\u91CD\u65B0\u67E5\u8A62",
    onClick: () => window.location.reload()
  })));
}